////////////////////////////////////////////////////////////////////////
// venture.wdl
//
////////////////////////////////////////////////////////////////////////
// Module        : venture.wdl
// Version       : 2.1
// Date          : 25.4.00   (@138)
// Responsible   : Doug Poston
// Desc: This script file contains actions that can be used to help create
//      adventure (RPG) type games.
//
// Notes: must be included after MENU.WDL
////////////////////////////////////////////////////////////////////////


/// GENERAL VENTURE SKILLS, STRINGS, AND DEFINES ////////////////////////
SKILL	venture_temp {};	// temporary value used by venture.wdl actions
SKILL venture_return {};// return value used by venture.wdl actions
SKILL __ICON_ACTIVE {VAL OFF;}    // flag: ON-let player view inventory, character stats,
											 //      and the main menu.
DEFINE __BUSY,FLAG8; 	// used to avoid double triggered actions (similar to "MY_MOVING")

SOUND klick_snd, <klick.wav>;       // "klick" sound





/// GENERAL ADVENTURE TEXT PREDEFINE ////////////////////////
IFNDEF ADV_DEF_ADVENTURE_TEXT;		// predefine keyword
// use general purpose adventure text
STRING wrong_key_str, "This key doesn't fit!";
STRING wrong_item_str, "Try another item!";
STRING wrong_type_str, "Nothing happened!";
STRING level_info_str, "You made a level!
You may share   bonus points!";

// starting menu chooses
STRING start1_str, "


        Start new game

        Load game

        Exit Game";

STRING bonus_info_str,
  "\nYou may share   bonus points!      Finished";

// Character stats
STRING char_pan_str, "             Character Skills


   Hitpoints:   /       Bravery:

   Mana:        /       Intuition:

   Strength:    /       Level:

   Agility:             Experiencep.:

                        Next Level:
                        ";


// Online help
STRING help_str"Keyboard commands

F1  - Help           C  - Character
F2  - Save           I  - Inventory
F3  - Load       Space  - Weapon on/off
F10 - Exit         Home - Jump

Mouse Right       - Mouse on/off
Mouse Left / Ctrl - Fight
Pg Up / Pg Dn     - Look up/down";


// Main Menu string
STRING menu_str, //*
"


        Start new game

        Save game

        Load game

        Exit game

        Resume game

        Help

        Credits
        ";

// AD (after death) Menu string
STRING admenu_str, //*
"


        Start new game

        Save game

        Load game

        Exit game

        Help

        Credits
        ";

// Exit menu (yes/no)
STRING exit_str, "
Quit your adventure?



        Yes

        No";

// exit text (displayed in exit window)
STRING vstr_exit_txt,
"Thank You for playing this demo!
CONITEC Datensysteme (www.conitec.com)
____________________________________________
The entire demo was developed with 3D GameStudio / A4.
____________________________________________
";


// credit string
STRING credit_str, "
Developed with the ACKNEX engine and toolkit:
3D GAME STUDIO (tm)
Visit the Conitec Website:
www.conitec.com";

STRING vent_blank_str, "


                      ";

ENDIF; // end general purpose adventure text




//////////////////////// SCREEN /////////////////////////////////////////


IFNDEF ADV_DEF_SCREEN_MAPS;    // predefine keyword
  BMAP button_map, <ventbutt.pcx>;    		// button bitmap

  BMAP char_button_map, <ventback.bmp>, 535, 0, 60, 100;       // icon for character button
  BMAP inv_button_map, <ventback.bmp>, 530, 120, 70, 85;       // icon for inventory button
  BMAP menu_button_map, <ventback.bmp>, 570, 210, 70, 70;      // icon for menu button
  BMAP screen_map, <ventback.bmp>;                             // the entire screen map
  BMAP hpbar_map, <redbar.pcx>;                                // hitpoint bar map
  BMAP strbar_map, <grnbar.pcx>;                               // strength bar map
  BMAP manabar_map, <bluebar.pcx>;                             // mana bar map
  BMAP info1_map, <ventinfo.bmp>;        								// info1 panel bitmap (used for save and load)
  BMAP info2_map, <ventdia.bmp>;   										// small info-text panel

  FONT panel_font, <ventfont.pcx>,8,10;    	// panel font bitmap

  DEFINE  SCREEN_STAT_HP_BAR_X     540;      // X offset for the hitpoints bar
  DEFINE  SCREEN_STAT_HP_BAR_Y      10;      // Y offset for the hitpoints bar
  DEFINE  SCREEN_STAT_STR_BAR_X    555;      // X offset for the strength bar
  DEFINE  SCREEN_STAT_STR_BAR_Y     10;      // Y offset for the strength bar
  DEFINE  SCREEN_STAT_MANA_BAR_X   570;      // X offset for the mana bar
  DEFINE  SCREEN_STAT_MANA_BAR_Y    10;      // Y offset for the mana bar

  DEFINE  SCREEN_STAT_BAR_HEIGHT    80;      // the height of the stat bars

  DEFINE  SCREEN_STAT_BAR_FACTOR  1.0;// 0.8;      // vertical shifting factor

  BMAP blood_splash_map <redf.pcx>;          // blood red splash (shown when player is damaged)
  BMAP black_map <blackf.pcx>;               // blackout bitmap (used for fades)

ENDIF;



/// screen skills ////////////////////////

SKILL statbar_pan_hp {}           		// player's stat bar panel values (hp, strength, mana)
SKILL statbar_pan_str {}
SKILL statbar_pan_mana {}


/// screen text ////////////////////////

// Desc: information text
TEXT info1_txt
{
	POS_X 80;
	POS_Y 280;
	LAYER 5;
	FONT panel_font;
	STRING vent_blank_str;
}

// Desc: information text
TEXT info2_txt
{
	POS_X 80;
	POS_Y 355;
	LAYER 5;
	FONT panel_font;
	STRING vent_blank_str;
}

// Desc: bonus info text
TEXT bonus_info_txt
{
	POS_X 84;
	POS_Y 430;
	LAYER 5;
	FONT panel_font;
	STRING bonus_info_str;
}


/// screen panels ////////////////////////

// Desc: 3 vertical bar graphs to display the player's stats (hp, str, & mana)
PANEL statbar_pan
{
	// Vertical bar graph display for the player's stats
	VBAR SCREEN_STAT_HP_BAR_X, SCREEN_STAT_HP_BAR_Y, SCREEN_STAT_BAR_HEIGHT,
	    hpbar_map, SCREEN_STAT_BAR_FACTOR, statbar_pan_hp;
	VBAR SCREEN_STAT_STR_BAR_X, SCREEN_STAT_STR_BAR_Y, SCREEN_STAT_BAR_HEIGHT,
	    strbar_map, SCREEN_STAT_BAR_FACTOR, statbar_pan_str;
	VBAR SCREEN_STAT_MANA_BAR_X, SCREEN_STAT_MANA_BAR_Y, SCREEN_STAT_BAR_HEIGHT,
	    manabar_map, SCREEN_STAT_BAR_FACTOR, statbar_pan_mana;
	LAYER 7;
	FLAGS REFRESH, VISIBLE;
}

// Desc: Main screen panel
PANEL screen_pan
{
	BMAP screen_map;
	BUTTON 535, 0, char_button_map, NULL, NULL, vpst_toggle_char, NULL, NULL;
	BUTTON 530, 120, inv_button_map, NULL, NULL, vinv_toggle_inventory, NULL, NULL;
	BUTTON 570, 210, menu_button_map, NULL, NULL, vscr_toggle_menu, NULL, NULL;
	LAYER 2;
	FLAGS OVERLAY, REFRESH, VISIBLE;
}


// Desc: large information panel (used for stats, ??? ??? and ???)
PANEL info1_pan
{
	POS_X 61;
	POS_Y 265;
	BMAP info1_map;
	LAYER 3;
	FLAGS REFRESH, OVERLAY;
}


// Desc: this panel is used to display information at the bottom of the
//      player's screen.
PANEL info2_pan
{
	POS_X 61;
	POS_Y 344;
	BMAP info2_map;
	LAYER 3;
	FLAGS REFRESH, OVERLAY;
}



/// button panels ////////////////////////
// (postfix '_vbpan')

// Desc: common vscr_close_all button (lower center)
PANEL info_exit_vbpan
{
	POS_X 61;
	POS_Y 265;
	BUTTON 200, 180, button_map, button_map, button_map, vscr_close_all, NULL, NULL;
	LAYER 4;
	FLAGS REFRESH, OVERLAY;
}

// Desc: common vscr_close_all button (lower right side)
PANEL info_exit_right_vbpan
{
	POS_X 61;
	POS_Y 265;
	BUTTON 375, 175, button_map, button_map, button_map, vscr_close_all, NULL, NULL;
	LAYER 4;
	FLAGS REFRESH, OVERLAY;
}

// Desc: button in lower right that brings up the startmenu
PANEL intro_exit_vbpan
{
	POS_X 61;
	POS_Y 265;
	BUTTON 375, 175, button_map, button_map, button_map, vscr_show_startmenu, NULL, NULL;
	LAYER 4;
	FLAGS REFRESH, OVERLAY;
}

// Desc: start menu buttons
PANEL start_menu_vbpan
{
	POS_X 61;
	POS_Y 265;
	LAYER 4;
	BUTTON 45, 40, button_map, button_map, button_map, vpst_show_create_character, NULL, NULL;
	BUTTON 45, 60, button_map, button_map, button_map, vpic_load, NULL, NULL;
	BUTTON 45, 80, button_map, button_map, button_map, vscr_show_start_exit, NULL, NULL;
	FLAGS REFRESH, OVERLAY;
}

// Desc: button panel for main menu
PANEL main_menu_vbpan
{
	POS_X 61;
	POS_Y 265;
	LAYER 4;
	BUTTON 45, 40, button_map, button_map, button_map, main, NULL, NULL;
	BUTTON 45, 60, button_map, button_map, button_map, vpic_save, NULL, NULL;
	BUTTON 45, 80, button_map, button_map, button_map, vpic_load, NULL, NULL;
	BUTTON 45, 100, button_map, button_map, button_map, vscr_show_exit, NULL, NULL;
	BUTTON 45, 120, button_map, button_map, button_map, vscr_close_all, NULL, NULL;   // resume
	BUTTON 45, 140, button_map, button_map, button_map, vscr_show_help, NULL, NULL;
	BUTTON 45, 160, button_map, button_map, button_map, vscr_show_credits, NULL, NULL;
	FLAGS REFRESH;
}

// Desc: button panel for admenu
PANEL admenu_vbpan
{
	POS_X 61;
	POS_Y 265;
	LAYER 4;
	BUTTON 45, 40, button_map, button_map, button_map, main, NULL, NULL;
	BUTTON 45, 60, button_map, button_map, button_map, vpic_save, NULL, NULL;
	BUTTON 45, 80, button_map, button_map, button_map, vpic_load, NULL, NULL;
	BUTTON 45, 100, button_map, button_map, button_map, vscr_show_exit, NULL, NULL;
	BUTTON 45, 120, button_map, button_map, button_map, vscr_show_help, NULL, NULL;
	BUTTON 45, 140, button_map, button_map, button_map, vscr_show_credits, NULL, NULL;
	FLAGS REFRESH;
}

// Desc: button panel to confirm exit
PANEL exit_vbpan
{
	POS_X 61;
	POS_Y 344;
	LAYER 4;
	BUTTON 40, 60, button_map, button_map, button_map, vmsc_exit, NULL, NULL;
	BUTTON 40, 80, button_map, button_map, button_map, vscr_close_all, NULL, NULL;
	FLAGS REFRESH;
}

// Desc: button panel to confirm exit (that returns to the startmenu on no)
PANEL start_exit_vbpan
{
	POS_X 61;
	POS_Y 344;
	LAYER 4;
	BUTTON 40, 60, button_map, button_map, button_map, vmsc_exit, NULL, NULL;
	BUTTON 40, 80, button_map, button_map, button_map, vscr_show_startmenu, NULL, NULL;
	FLAGS REFRESH;
}


/// screen 'fx' panels ////////////////////////

// Desc: blood splash panel (used to notify the player's been hit)
PANEL blood_pan
{
	POS_X 3;
	POS_Y 4;
	LAYER 2;
	BMAP blood_splash_map;
	FLAGS REFRESH, OVERLAY;
}

// Desc: Blackout panels set at different levels (13, 14, 15, 16)
PANEL blackTop16_pan
{
	BMAP black_map;
	LAYER 16;
	FLAGS REFRESH;
}
PANEL blackTop15_pan
{
	BMAP black_map;
	LAYER 15;
	FLAGS REFRESH, TRANSPARENT;
}
PANEL blackTop14_pan
{
	BMAP black_map;
	LAYER 14;
	FLAGS REFRESH, TRANSPARENT;
}
PANEL blackTop13_pan
{
	BMAP black_map;
	LAYER 13;
	FLAGS REFRESH, TRANSPARENT;
}




/// screen actions ////////////////////////

// Desc: fade out to black.
ACTION vscr_fade_out
{
	SET blackTop13_pan.VISIBLE, ON;
	WAITT 1;
	SET blackTop14_pan.VISIBLE, ON;
	WAITT 1;
	SET blackTop15_pan.VISIBLE, ON;
	WAITT 1;
	SET blackTop16_pan.VISIBLE, ON;
	WAITT 1;
}

// Desc: fade in from black
ACTION vscr_fade_in
{
	SET blackTop16_pan.VISIBLE, OFF;
	WAITT 1;
	SET blackTop15_pan.VISIBLE, OFF;
	WAITT 1;
	SET blackTop14_pan.VISIBLE, OFF;
	WAITT 1;
	SET blackTop13_pan.VISIBLE, OFF;
	WAITT 1;
}

// Desc: black out screen
ACTION vscr_black_out
{
	SET blackTop13_pan.VISIBLE, ON;
	SET blackTop14_pan.VISIBLE, ON;
	SET blackTop15_pan.VISIBLE, ON;
	SET blackTop16_pan.VISIBLE, ON;

}

// Desc: Toggle synonyms
SYNONYM menu_toggle_syn {TYPE ACTION;DEFAULT vscr_show_menu;}   // switch between vscr_show_menu and vscr_close_all
SYNONYM help_toggle_syn {TYPE ACTION; DEFAULT vscr_show_help;}  // switch between vscr_show_help and vscr_close_all
SYNONYM credit_toggle_syn {TYPE ACTION; DEFAULT vscr_show_credits;}  // switch between vscr_show_credits and vscr_close_all

// Desc: Toggle synonym actions
ACTION vscr_toggle_menu
{
	CALL menu_toggle_syn;      // show/hide menu
}
ACTION vscr_toggle_help
{
	CALL help_toggle_syn;      // show/hide menu
}
ACTION vscr_toggle_credits
{
	CALL credit_toggle_syn;      // show/hide menu
}


// Desc: show the main menu
ACTION vscr_show_menu
{
	// if icons are not active...
	IF (__ICON_ACTIVE == OFF)
	{
		// do not show main menu
		RETURN;
	}
	CALL vscr_close_all;                // close all the other panels
	SET info1_pan.VISIBLE, ON;          // use info1_pan as background
	SET main_menu_vbpan.VISIBLE, ON;    // show main menu button panel
	SET info1_txt.STRING, menu_str;     // set menu string
	SET info1_txt.VISIBLE, ON;          // show text
	SET menu_toggle_syn, vscr_close_all;// set toggle to close all panels (including menu)
}

// Desc: show the 'after-death' menu
ACTION vscr_show_admenu
{
	CALL vscr_close_all_at_end;        	// close all the other panels
	SET info1_pan.VISIBLE, ON;          // use large panel
	SET admenu_vbpan.VISIBLE, ON;       // show buttons
	SET info1_txt.STRING, admenu_str;   // set text
	SET info1_txt.VISIBLE, ON;       	// show text
}

// Desc: show the help panel
ACTION vscr_show_help
{
	CALL vscr_close_all;                   // close all the other panels
	SET info1_pan.VISIBLE,ON;        		// use large panel
	SET info_exit_right_vbpan.VISIBLE, ON;	// exit button (vscr_close_all)
	SET info1_txt.STRING, help_str;        // set string
	SET info1_txt.VISIBLE,ON;              // show string
	SET help_toggle_syn, vscr_close_all;   // set toggle to close all
}

// Desc: show the credit screen
ACTION vscr_show_credits
{
	CALL vscr_close_all;                   // close all the other panels
	SET info1_pan.VISIBLE, ON;         		// use large panel
	SET info_exit_right_vbpan.VISIBLE, ON;	// exit button (vscr_close_all)
	SET info1_txt.STRING, credit_str;      // set string
	SET info1_txt.VISIBLE, ON;             // show string
	SET credit_toggle_syn, vscr_close_all; // set toggle to close all
}

// Desc: show the startmenu
ACTION vscr_show_startmenu
{
	CALL vscr_close_all_at_start;       // close all the other panels
	SET info1_pan.VISIBLE, ON;          // use large panel
	SET start_menu_vbpan.VISIBLE, ON;	// startmenu buttons
	SET info1_txt.STRING, start1_str;   // set string
	SET info1_txt.VISIBLE, ON;          // show string
	SET ON_ESC, vscr_show_start_exit;   // exit on ESC
	SET ON_F10, vscr_show_start_exit;   // exit on F10
}



// Desc: show the exit menu
ACTION vscr_show_exit
{
	CALL vscr_close_all;                // close all
	SET info2_pan.VISIBLE, ON;       	// use smaller panel
	SET exit_vbpan.VISIBLE, ON;         // show buttons
	SET info2_txt.STRING, exit_str;     // set string
	SET info2_txt.VISIBLE, ON;          // show string
 	SET ON_ESC, vscr_close_all;		  	// ON_ESC or N	 close all
	SET ON_N, vscr_close_all;
	SET ON_Y, vmsc_exit;                // ON_Y or J exit
	SET ON_J, vmsc_exit;
}

// Desc: show exit menu, on no return to the start menu
ACTION vscr_show_start_exit
{
	CALL vscr_close_all_at_start;       // close all, reset keys
	SET info2_pan.VISIBLE, ON;          // use smaller panel
	SET start_exit_vbpan.VISIBLE, ON;   // show buttons
	SET info2_txt.STRING, exit_str;     // set string
	SET info2_txt.VISIBLE, ON;          // show string
	SET ON_ESC, vscr_show_startmenu;    // ON_ESC or N return to start menu
	SET ON_N, vscr_show_startmenu;
	SET ON_Y, vmsc_exit;              	// ON_Y or J exit
	SET ON_J, vmsc_exit;
}


// Desc: Show the info text for an object
//
// NOTE: ME must have a valid STRING2.
ACTION vscr_show_info
{
	CALL vscr_close_all;
	SET info2_pan.VISIBLE, ON;
	SET info_exit_right_vbpan.VISIBLE, ON;
	SET info2_txt.STRING, MY.STRING2;
	SET info2_txt.VISIBLE, ON;
}


// NOTE: SCREEN ACTIONS CONTINUE AT BOTTOM OF FILE!



//////////////////////// PICTURE SAVE ///////////////////////////////////

/// picture save predefines ////////////////////////
IFNDEF ADV_DEF_SAVE_LOAD;
 DEFINE PICSIZE_X 64; // 320x240 shrinked by 5
 DEFINE PICSIZE_Y 48;

 BMAP slot1_map <white.pcx>,0,0,PICSIZE_X,PICSIZE_Y;  // default save image
 BMAP slot2_map <white.pcx>,0,0,PICSIZE_X,PICSIZE_Y;
 BMAP slot3_map <white.pcx>,0,0,PICSIZE_X,PICSIZE_Y;
 BMAP slot4_map <white.pcx>,0,0,PICSIZE_X,PICSIZE_Y;

 DEFINE PICSAVE_BKGD;											// panel has background
 BMAP picsavebk_map <black.pcx>,0,0,170,140;
 DEFINE picloadbk_map picsavebk_map;

 DEFINE panel_font,standard_font;

 DEFINE PICSLOT1_X 10;
 DEFINE PICSLOT1_Y 10;
 DEFINE PICSLOT2_X 84;
 DEFINE PICSLOT2_Y 10;
 DEFINE PICSLOT3_X 10;
 DEFINE PICSLOT3_Y 68;
 DEFINE PICSLOT4_X 84;
 DEFINE PICSLOT4_Y 68;
 DEFINE PICEXIT_X  160;
 DEFINE PICEXIT_Y  130;
// DEFINE PICSAVE_TEXT;	// uncomment to have titles for each slot
ENDIF;






/// picture save skills ////////////////////////
SKILL picsave_pos { X 4; Y 4; }	// panel position
SKILL pictext_offs { VAL 60; }		// distance picture to title
SKILL __SAVING { VAL OFF; }
SKILL picfreeze_fac { VAL 5; }

/// picture save panels ////////////////////////
// Desc: save panel
PANEL picsave_pan
{
IFDEF PICSAVE_BKGD;
	BMAP picsavebk_map;
ENDIF;
	LAYER 10;
	BUTTON PICSLOT1_X,PICSLOT1_Y,slot1_map,slot1_map,slot1_map,_vpic_save1,NULL,NULL;
	BUTTON PICSLOT2_X,PICSLOT2_Y,slot2_map,slot2_map,slot2_map,_vpic_save2,NULL,NULL;
	BUTTON PICSLOT3_X,PICSLOT3_Y,slot3_map,slot3_map,slot3_map,_vpic_save3,NULL,NULL;
	BUTTON PICSLOT4_X,PICSLOT4_Y,slot4_map,slot4_map,slot4_map,_vpic_save4,NULL,NULL;
	BUTTON PICEXIT_X,PICEXIT_Y,button_map,button_map,button_map,_vpic_save_hide,NULL,NULL;
	FLAGS REFRESH;
}

// Desc: load panel
PANEL picload_pan
{
IFDEF PICSAVE_BKGD;
	BMAP picloadbk_map;
ENDIF;
	LAYER 10;
	BUTTON PICSLOT1_X,PICSLOT1_Y,slot1_map,slot1_map,slot1_map,_vpic_load1,NULL,NULL;
	BUTTON PICSLOT2_X,PICSLOT2_Y,slot2_map,slot2_map,slot2_map,_vpic_load2,NULL,NULL;
	BUTTON PICSLOT3_X,PICSLOT3_Y,slot3_map,slot3_map,slot3_map,_vpic_load3,NULL,NULL;
	BUTTON PICSLOT4_X,PICSLOT4_Y,slot4_map,slot4_map,slot4_map,_vpic_load4,NULL,NULL;
	BUTTON PICEXIT_X,PICEXIT_Y,button_map,button_map,button_map,_vpic_save_hide,NULL,NULL;
	FLAGS REFRESH;
}

/// picture save text ////////////////////////
IFDEF PICSAVE_TEXT;
	TEXT picsave1_txt { LAYER 11; FONT panel_font; STRING name1_str; }
	TEXT picsave2_txt { LAYER 11;	FONT panel_font; STRING name2_str; }
	TEXT picsave3_txt { LAYER 11; FONT panel_font; STRING name3_str; }
	TEXT picsave4_txt { LAYER 11;	FONT panel_font; STRING name4_str; }
ENDIF;


/// picture save actions ////////////////////////
// Desc: toggle the save game panel on and off
ACTION vpic_save
{
	CALL _buttonclick;
// let panel disappear on second key press
	IF (picsave_pan.VISIBLE == ON) {
		CALL _vpic_save_hide;
	} ELSE {
		SET picsave_pan.VISIBLE,ON;
		CALL _vpic_save_show;
	}
}

// Desc: toggle load game panel on and off
ACTION vpic_load
{
	CALL _buttonclick;

	// hide panel if visible
	IF (picload_pan.VISIBLE == ON)
	{
		CALL _vpic_save_hide;
	}
	ELSE	// show panel if hidden
	{
		SET picload_pan.VISIBLE,ON;
		CALL _vpic_save_show;
	}
}



// Desc: set everything visible
ACTION _vpic_save_show
{
	picsave_pan.POS_X = picsave_pos.X;
	picsave_pan.POS_Y = picsave_pos.Y;
	picload_pan.POS_X = picsave_pos.X;
	picload_pan.POS_Y = picsave_pos.Y;
IFDEF PICSAVE_TEXT;
	picsave1_txt.POS_X = picsave_pos.X + PICSLOT1_X;
	picsave1_txt.POS_Y = picsave_pos.Y + PICSLOT1_Y + pictext_offs;
	picsave2_txt.POS_X = picsave_pos.X + PICSLOT2_X;
	picsave2_txt.POS_Y = picsave_pos.Y + PICSLOT2_Y + pictext_offs;
	picsave3_txt.POS_X = picsave_pos.X + PICSLOT3_X;
	picsave3_txt.POS_Y = picsave_pos.Y + PICSLOT3_Y + pictext_offs;
	picsave4_txt.POS_X = picsave_pos.X + PICSLOT4_X;
	picsave4_txt.POS_Y = picsave_pos.Y + PICSLOT4_Y + pictext_offs;
	SET picsave1_txt.VISIBLE,ON;
	SET picsave2_txt.VISIBLE,ON;
	SET picsave3_txt.VISIBLE,ON;
	SET picsave4_txt.VISIBLE,ON;
ENDIF;
	RETURN;
}


// Desc: hide everything
ACTION _vpic_save_hide
{
	SET picsave_pan.VISIBLE,OFF;
	SET picload_pan.VISIBLE,OFF;
IFDEF PICSAVE_TEXT;
	SET picsave1_txt.VISIBLE,OFF;
	SET picsave2_txt.VISIBLE,OFF;
	SET picsave3_txt.VISIBLE,OFF;
	SET picsave4_txt.VISIBLE,OFF;
ENDIF;
	picfreeze_fac = SCREEN_SIZE.X / PICSIZE_X;
	RETURN;
}


// Desc: save actions for each button
ACTION _vpic_save1
{
	IF (__SAVING != OFF)
	{
		RETURN; 	// prevent clicking a pic during save
	}
	slot = 1;
	SET mystring,name1_str;
	CALL _vpic_save_hide;	// hide panel to do the screenshot
	FREEZE_MAP slot1_map,picfreeze_fac,0;
	BRANCH _vpic_save;
}
ACTION _vpic_save2
{
	IF (__SAVING != OFF)
	{
		RETURN; 	// prevent clicking a pic during save
	}
	slot = 2;
	CALL _vpic_save_hide;
	FREEZE_MAP slot2_map,picfreeze_fac,0;
	SET mystring,name2_str;
	BRANCH _vpic_save;
}
ACTION _vpic_save3
{
	IF (__SAVING != OFF)
	{
		RETURN; 	// prevent clicking a pic during save
	}
	slot = 3;
	CALL _vpic_save_hide;
	FREEZE_MAP slot3_map,picfreeze_fac,0;
	SET mystring,name3_str;
	BRANCH _vpic_save;
}
ACTION _vpic_save4
{
 	IF (__SAVING != OFF)
	{
		RETURN; 	// prevent clicking a pic during save
	}
	slot = 4;
	CALL _vpic_save_hide;
	FREEZE_MAP slot4_map,picfreeze_fac,0;
	SET mystring,name4_str;
	BRANCH _vpic_save;
}

// Desc: finish saving action (called from _vpic_save1..4)
ACTION _vpic_save
{
	__SAVING = ON;		// prevent clicking another picture
	WAIT 1;				// at this time the screenshot is done
	SET picsave_pan.VISIBLE,ON;
	CALL _vpic_save_show;	// so the panel may appear again
IFDEF PICSAVE_TEXT;
	INKEY mystring;		// enter title
	IF (RESULT != 13) {	// Aborted with ESC
		__SAVING = OFF;		// enable picsaving again
		CALL load_status;	// restore old picture
		CALL _vpic_save_hide;
		END;
	}
IFELSE;
	WAIT 2;
ENDIF;
	__SAVING = OFF;	// enable picsaving again
	CALL _vpic_save_hide;
	CALL save_status;
	SAVE SAVE_NAME,slot;
	IF (RESULT > 0) { CALL _buttonclick; }
	WAIT	1;
	CALL load_status;	// to be performed in LOAD: restore old picture
}

// Desc: load for each panel
ACTION _vpic_load1
{
	slot = 1;
	BRANCH _vpic_load;
}
ACTION _vpic_load2
{
	slot = 2;
	BRANCH _vpic_load;
}
ACTION _vpic_load3
{
	slot = 3;
	BRANCH _vpic_load;
}
ACTION _vpic_load4
{
	slot = 4;
	BRANCH _vpic_load;
}

// Desc: load game
ACTION _vpic_load
{
	CALL _buttonclick;
	LOAD SAVE_NAME,slot;
	IF (RESULT < 0) { beep; }
	WAIT 1;
	CALL _vpic_save_hide;
}





//////////////////////// NPC ////////////////////////////////////////////
// action used to control NPC (non-player characters)

/// entity defines ////////////////////////
DEFINE ENT_SCALE, SKILL33;	// entity scale
DEFINE ENT_ID, SKILL34; 			// entity ID


/// npc defines ////////////////////////
SYNONYM NPC_ENTITY {TYPE ENTITY;}	// hold NPC entity

DEFINE _NPC_WALK, 1; 	// npc standard navigation
DEFINE _NPC_COME, 2; 	// npc follows
DEFINE _NPC_ATTACK, 3; 	// npc attacks
DEFINE _NPC_RETREAT 4; 	// npc retreats
DEFINE _NPC_STOP, 5; 	// npc waits
DEFINE _NPC_TALK, 6; 	// npc starts talking
DEFINE _NPC_DEAD, 7;		// npc is dead


/// npc predefines ////////////////////////
IFNDEF ADV_DEF_NPC;
	SKILL vsk_nav_speed {X 10;Y 0;Z 0;}      // navigation speed vector
ENDIF;


/// npc skills ////////////////////////
SKILL vsk_time_nav_speed {}              // navigation speed adjusted for time


/// npc actions ////////////////////////

// Desc: used to control the invisible navigation entity
//       "CREATE <arrow.pcx>, MY.POS, vnpc_random_navigation;"
ACTION vnpc_random_navigation
{
	SET YOUR.ENTITY1, ME;
	SET MY.INVISIBLE, ON;
	SET MY.PAN, 0;
	SET MY.ROLL, 0;
	SET MY.TILT, 0;
	SET MY.EVENT, _vnpc_random_nav_event;
	SET MY.ENABLE_BLOCK, 1;
	SET MY.ENABLE_ENTITY, 1;
	WHILE (1)
	{
		vsk_time_nav_speed = vsk_nav_speed * TIME;
		SET YOU,NULL;
		MOVE ME, vsk_time_nav_speed, nullskill;
		WAIT 1;
	}
}


// Desc: if the navigator collides anywhere it changes its direction randomly
ACTION _vnpc_random_nav_event
{
	IF ( (EVENT_TYPE == EVENT_BLOCK) ||  (EVENT_TYPE == EVENT_ENTITY))
	{
		MY.PAN = RANDOM (180)+MY.PAN;
	}
}




//////////////////////// PLAYER STAT ////////////////////////////////////

/// player stat predefines ////////////////////////
IFNDEF ADV_DEF_PLAYERSTATS;
 	DEFINE	PLAYER_LEVEL_TWO_EXP		1000;   // experience need for each level
	DEFINE	PLAYER_LEVEL_THREE_EXP	2500;
	DEFINE	PLAYER_LEVEL_FOUR_EXP	5000;
	DEFINE	PLAYER_LEVEL_FIVE_EXP	8000;   // this value is then doubled for each level after this one
														  // (ex. 6 = 16000, 7 = 32000, 8 = 64000)



  ///////// player skills /////////////////
  SKILL player_hp {VAL 20;}  				// player's base hitpoints
  SKILL player_mana {VAL 0;}         	// player's base mana level
  SKILL player_str {VAL 15;}          	// player's base strength
  SKILL player_gew {VAL 15;}          	// player's base agility
  SKILL player_mut {VAL 15;}          	// player's base bravery
  SKILL player_int {VAL 15;}          	// player's base intuition

  DEFINE	PLAYER_RAND_HP 5;					// the random amount of hitpoints added
  DEFINE	PLAYER_RAND_MANA 0;				// the random amount of mana added
  DEFINE	PLAYER_RAND_STR 25;				// the random amount of strength added
  DEFINE	PLAYER_RAND_GEW 25;				// the random amount of agility added
  DEFINE	PLAYER_RAND_MUT 25;				// the random amount of bravery added
  DEFINE	PLAYER_RAND_INT 25;				// the random amount of intuition added

  DEFINE PLAYER_BONUS_PER_LVL	10;		// number of bonus points awarded each level

  DEFINE PLAYER_PERIODIC_HP	0.008; 	// number of hitpoints points regenerated every tick
  DEFINE PLAYER_PERIODIC_STR	0.050; 	// number of strength points regenerated every tick
  DEFINE PLAYER_PERIODIC_MANA	0.008; 	// number of mana points regenerated every tick
ENDIF;


/// player stat skills ////////////////////////
SKILL next_lvl_exp {VAL PLAYER_LEVEL_TWO_EXP;}      // number of experience points need for the next level

SKILL player_current_hp {}		// player's current hitpoints
SKILL player_current_mana {}  	// player's current mana level
SKILL player_current_str {}  	// player's current strength

SKILL player_bonus_pts {VAL PLAYER_BONUS_PER_LVL;}     	// player's bonus points (to spend on stats)

SKILL player_exp {VAL 0;}           	// player's experience points

SKILL player_lvl {VAL 1;}           	// player's current level

SKILL give_exp {VAL 0;}              	// the amount of exp to give the player


/// player stat panels ////////////////////////

// Desc: bonus points panel
PANEL bonus_pan
{
	POS_X 61;
	POS_Y 265;
	BUTTON 15, 40, button_map, button_map, button_map, _vpst_bonus_hp, NULL, NULL;
	BUTTON 15, 60, button_map, button_map, button_map, _vpst_bonus_mana, NULL, NULL;
	BUTTON 15, 80, button_map, button_map, button_map, _vpst_bonus_str, NULL, NULL;
	BUTTON 15, 100, button_map, button_map, button_map, _vpst_bonus_gew, NULL, NULL;
	BUTTON 180, 40, button_map, button_map, button_map, _vpst_bonus_mut, NULL, NULL;
	BUTTON 180, 60, button_map, button_map, button_map, _vpst_bonus_int, NULL, NULL;
	DIGITS 130, 175, 2, panel_font, 1, player_bonus_pts;
	LAYER 4;
	FLAGS REFRESH, OVERLAY;
}

// Desc: character stats panel
PANEL char_pan
{
	POS_X 65;
	POS_Y 265;
	DIGITS 125, 45, 2, panel_font, 1, player_current_hp;
	DIGITS 150, 45, 2, panel_font, 1, player_hp;
	DIGITS 125, 65, 2, panel_font, 1, player_current_mana;
	DIGITS 150, 65, 2, panel_font, 1, player_mana;
	DIGITS 125, 85, 2, panel_font, 1, player_current_str;
	DIGITS 150, 85, 2, panel_font, 1, player_str;
	DIGITS 150, 105, 2, panel_font, 1, player_gew;
	DIGITS 350, 45, 2, panel_font, 1, player_mut;
	DIGITS 350, 65, 2, panel_font, 1, player_int;
	DIGITS 350, 85, 2, panel_font, 1, player_lvl;
	DIGITS 325, 105, 5, panel_font, 1, player_exp;
	DIGITS 325, 125, 5, panel_font, 1, next_lvl_exp;
	LAYER 4;
	FLAGS REFRESH, OVERLAY;
}


/// player stat actions ////////////////////////

// Desc: initialize the player's base stats
ACTION vpst_init_stats
{
   player_hp += RANDOM (PLAYER_RAND_HP);     	// calculate base hitpoints
	player_current_hp = player_hp;
   player_mana += RANDOM (PLAYER_RAND_MANA);    // calculate base mana
	player_current_mana = player_mana;
  	player_str += RANDOM (PLAYER_RAND_STR);      // calculate base strength
	player_current_str = player_str;

	player_gew += RANDOM (PLAYER_RAND_GEW);
	player_mut += RANDOM (PLAYER_RAND_MUT);
	player_int += RANDOM (PLAYER_RAND_INT);
}


// Desc: create the character and show the bonus panel
ACTION vpst_show_create_character
{
	CALL vpst_init_stats;
	CALL vpst_show_bonus;
}


SYNONYM char_toggle_syn {TYPE ACTION;DEFAULT vpst_show_char;}   // switch between vscr_show_menu and vscr_close_all

// Desc: toggle between showing and hiding the character window
ACTION vpst_toggle_char
{
	CALL char_toggle_syn;      // show/hide inventory
}


// Desc: show the player's stats panel
ACTION vpst_show_char
{
	// if icons are not active...
	IF (__ICON_ACTIVE == OFF)
	{
		// don't show character stat panel
		RETURN;
	}
	IF (player_bonus_pts > 0)
	{
		CALL vpst_show_bonus;
		RETURN;
	}
	CALL vscr_close_all;
	SET info1_pan.VISIBLE, ON;
	SET char_pan.VISIBLE, ON;
	SET info_exit_vbpan.VISIBLE, ON;
	SET info1_txt.STRING, char_pan_str;
	SET info1_txt.VISIBLE, ON;
	SET char_toggle_syn, vscr_close_all;           // set toggle to close all panels (including character)
}


// Desc: show the player's stats panel and allow them to spend their bonus
//      points to increase their skills
ACTION vpst_show_bonus
{
	CALL vscr_close_all;
	SET info1_pan.VISIBLE, ON;
	SET char_pan.VISIBLE, ON;
	SET bonus_pan.VISIBLE, ON;
	SET bonus_info_txt.VISIBLE, ON;
	SET info1_txt.STRING, char_pan_str;
	SET info1_txt.VISIBLE, ON;
	SET info_exit_right_vbpan.VISIBLE, ON;
	SET char_toggle_syn, vscr_close_all;
}

// Desc: enable updates of the player's stats every tick by calling
//      _vpst_periodic_update action every tick
ACTION vpst_enable_periodic_update
{
	WHILE (1)
	{
		CALL _vpst_periodic_update;
		WAITT 1;
	}
}




// Desc: regenerate stats over time
//       update levels in life panel
//
// Called from vpst_stats_update
ACTION _vpst_periodic_update
{
	IF (player_current_hp < player_hp)
	{
		// regenerate hitpoints
		player_current_hp += PLAYER_PERIODIC_HP * TIME;
		IF (player_current_hp > player_hp)
		{
			player_current_hp = player_hp;
		}
	}
	IF (player_current_str < player_str)
	{
		// regenerate strength
		player_current_str += PLAYER_PERIODIC_STR * TIME;
		IF (player_current_str > player_str)
		{
			player_current_str = player_str;
		}
	}
	IF (player_current_mana < player_mana)
	{
		// regenerate mana
		player_current_mana += PLAYER_PERIODIC_MANA * TIME;
		IF (player_current_mana > player_mana)
		{
			player_current_mana = player_mana;
		}
	}

	// Update stat VBARs
	// the VBAR shows the percent of total hp/str/mana the player currently has
	// ( 100% = full bar, 50% = half bar, 0% = empty bar)
  	IF (player_hp > 0) // avoid divide by zero error
	{
		statbar_pan_hp = SCREEN_STAT_BAR_HEIGHT - INT (( player_current_hp/player_hp ) * SCREEN_STAT_BAR_HEIGHT);
	}
	ELSE   // empty bar
	{
		statbar_pan_hp = SCREEN_STAT_BAR_HEIGHT;
	}

	IF (player_str > 0)
	{
		statbar_pan_str = SCREEN_STAT_BAR_HEIGHT - INT (( player_current_str/player_str ) * SCREEN_STAT_BAR_HEIGHT);
	}
	ELSE
	{
		statbar_pan_mana = SCREEN_STAT_BAR_HEIGHT;
	}

	IF (player_mana > 0)
	{
		statbar_pan_mana = SCREEN_STAT_BAR_HEIGHT - INT (( player_current_mana/player_mana ) * SCREEN_STAT_BAR_HEIGHT);
	}
  	ELSE
	{
		statbar_pan_mana = SCREEN_STAT_BAR_HEIGHT;
	}
}


// Desc: Use a bonus point to increase player's base hitpoints
ACTION _vpst_bonus_hp
{
	IF (player_bonus_pts > 0)
	{
		player_hp += 1;
		player_current_hp += 1;
		player_bonus_pts -= 1;
	}
	ELSE
	{
		CALL vscr_close_all;
	}
}


// Desc: Use a bonus point to increase player's base strength
ACTION _vpst_bonus_str
{
	IF (player_bonus_pts > 0)
	{
		player_str += 1;
		player_current_str += 1;
		player_bonus_pts -= 1;
	}
	ELSE
	{
		CALL vscr_close_all;
	}
}

// Desc: Use a bonus point to increase player's base mana
ACTION _vpst_bonus_mana
{
	IF (player_bonus_pts > 0)
	{
		player_mana += 1;
		player_current_mana += 1;
		player_bonus_pts -= 1;
	}
	ELSE
	{
		CALL vscr_close_all;
	}
}

// Desc: Use a bonus point to increase player's agility
ACTION _vpst_bonus_gew
{
	IF (player_bonus_pts > 0)
	{
		player_gew += 1;
		player_bonus_pts += -1;
	}
	ELSE
	{
		CALL vscr_close_all;
	}
}


// Desc: Use a bonus point to increase player's bravery
ACTION _vpst_bonus_mut
{
	IF (player_bonus_pts > 0)
	{
		player_mut += 1;
		player_bonus_pts += -1;
	}
	ELSE
	{
		CALL vscr_close_all;
	}
}

// Desc: Use a bonus point to increase player's intuition
ACTION _vpst_bonus_int
{
	IF (player_bonus_pts > 0)
	{
		player_int += 1;
		player_bonus_pts += -1;
	}
	ELSE
	{
		CALL vscr_close_all;
	}
}

// Desc: Add the given experience (give_exp) to the player's experience (player_exp)
//      and check to see if the player has reached the next level.
//			If the player has reached the next level, CALL next_level
//
ACTION vpst_check_exp
{
	player_exp += give_exp;
	IF (player_exp >= next_lvl_exp)
	{
		CALL _vpst_next_level;
	}
	SET give_exp, 0;
}


// Desc: Set the player's level (player_lvl) and next level's experience goal
//      (next_lvl_exp).
//       Give the player ten bonus points for stats and open up their stats window.
ACTION _vpst_next_level
{
	IF (next_lvl_exp == PLAYER_LEVEL_FOUR_EXP)
	{
		SET next_lvl_exp, PLAYER_LEVEL_FIVE_EXP;
		SET player_lvl, 4;
	}
	IF (next_lvl_exp == PLAYER_LEVEL_THREE_EXP)
	{
		SET next_lvl_exp, PLAYER_LEVEL_FOUR_EXP;
		SET player_lvl, 3;
	}
	IF (next_lvl_exp == PLAYER_LEVEL_TWO_EXP)
	{
		SET next_lvl_exp, PLAYER_LEVEL_THREE_EXP;
		SET player_lvl, 2;
	}

	IF (player_lvl >= 4)
	{
		next_lvl_exp *= 2;
		player_lvl += 1;
	}

	player_bonus_pts += 10;
	SET bonus_info_txt.STRING, level_info_str;
	CALL vpst_show_char;
}




//////////////////////// ITEM ///////////////////////////////////////////

/// item predefines ////////////////////////
IFNDEF ADV_DEF_ITEMS;
  SOUND item_hit_snd,<sack.wav>;   // sound played when item hits ground
ENDIF;

/// item defines ////////////////////////
DEFINE _EMPTY, 0; 					// define inventory empty value

/// item skills ////////////////////////
SKILL mouse_object {VAL -1;}	// current object connected to mouse pointer
SKILL drop_dist {VAL 0;}      //

// item throwing
SKILL throw_grav { VAL 2; }
SKILL throw_speed { X 35; Y 0; Z 35; }
SKILL throw_angle { PAN 0; TILT 0; ROLL 0; }
SKILL throw_aspeed { PAN 0; TILT 5; ROLL 0; }



/// item actions ////////////////////////

// Desc: initialize item
ACTION vitm_init_item
{
	// SET FLAGS
	SET MY.ENABLE_TOUCH, ON; 	// mouse touch on
	SET MY.ENABLE_RELEASE, ON; // mouse release on
	SET MY.ENABLE_CLICK, ON;   // mouse click on
	SET MY.ENABLE_BLOCK, ON;  // block on
	SET MY.ENABLE_ENTITY,ON;  // collision with other entities on
	SET MY.EVENT, _vitm_item_event; 	// will be called at each event
	SET MY.PASSABLE, ON;

	// SCALE ITEM
	// make sure we have a valid item scale value
	IF (MY.ENT_SCALE == 0)
	{
		MY.ENT_SCALE = 1;
	}
	MY.SCALE_X = MY.ENT_SCALE;
	MY.SCALE_Y = MY.ENT_SCALE;
	MY.SCALE_Z = MY.ENT_SCALE;
}

// Desc: handle item event
ACTION _vitm_item_event
{
	IF (EVENT_TYPE == EVENT_CLICK)// mouseclick on item
	{
		IF (mouse_object <= _EMPTY)// if not empty, nothing will happen
		{
			// PICKUP ITEM
			mouse_object = MY.ENT_ID;	// the mouse gets the ENT_ID
			REMOVE ME; 						// the item disappears
			RETURN;
		}
	}
	// if the item was thrown away and collides:
	IF ( (EVENT_TYPE == EVENT_BLOCK) ||  (EVENT_TYPE == EVENT_ENTITY))
	{
		SET MY._SPEED, 0;          // stop moving
		SET MY.ENABLE_BLOCK, OFF;  // block off
		SET MY.ENABLE_ENTITY,OFF;  // collision with other entities off
		RETURN;
	}
	CALL handle_touch;	// show/hide touch text
}



// Desc: 'Use' an item
//       The default action for an item is to drop it
ACTION _vitm_use_item
{
   // NOT over something that produces touch_text...
	IF (touch_txt.VISIBLE == OFF)
	{
			CALL vitm_release_item; 	// drop_item
	}
}


// Desc: item is thrown from the player
//
// NOTE: ME must be set to an item
ACTION vitm_throw_item
{
	IF (player == NULL) { RETURN; }

	SET MY.FAT,OFF;
	SET MY.NARROW,ON;
	SET MY.PASSABLE,OFF;

	MY.X = player.X;
	MY.Y = player.Y;
	MY.Z = player.Z;

	MY.PAN = player.PAN + 180; 	//face the player
	MY.ROLL = 0;
	MY.TILT = 0;

	MY._SPEED_X = throw_speed.X;
	MY._SPEED_Y = 0;
	MY._SPEED_Z = throw_speed.Z;
	VECROTATE MY._SPEED,player.PAN;


	BRANCH _vitm_falling_item;

}

// Desc: item is dropped at player's feet
//
// NOTE: ME must be set to an item
ACTION vitm_drop_item
{
	IF (player == NULL)
	{
		RETURN;
	}

	SET MY.FAT,OFF;
	SET MY.NARROW,ON;
	SET MY.PASSABLE,OFF;

	MY.X = player.X;
	MY.Y = player.Y;
	MY.Z = player.Z;

	MY.PAN = player.PAN + 180; 	//face the player
	MY.ROLL = 0;
	MY.TILT = 0;

	// no speed
	MY._SPEED_X = 0;
	MY._SPEED_Y = 0;
	MY._SPEED_Z = 0;
	VECROTATE MY._SPEED,player.PAN;


	BRANCH _vitm_falling_item;

}


// Desc: create and 'release' the mouse_object item
ACTION vitm_release_item
{
	CALL vitm_create_item; 		// create an item depending on mouse_object
	WAIT 1;
	SET mouse_object, _EMPTY;  // empty the mouse object
}


ACTION	_vitm_falling_item
{
	WHILE (1)
	{
// check whether it hit the ground
		SONAR ME,1000;
		IF (RESULT <= 5)
		{
			PLAY_ENTSOUND ME,item_hit_snd,300;
			RETURN;
		}

// rotate the item
		MY.TILT += throw_aspeed.TILT*TIME;

// Add the world gravity force
		absforce.X = 0;
		absforce.Y = 0;
		absforce.Z = -throw_grav;
		ACCEL	MY._SPEED,absforce,air_fric;

		SET YOU,player;	// don't get stuck within the player
		MOVE ME,NULLSKILL,MY._SPEED;
		WAIT 1;
	}

}


// Desc: create an item with an attached action depending on the cursor sprite
// NOTE: this action should be OVERRIDDEN by the game script
ACTION vitm_create_item
{
	WAIT 1;
}




//////////////////////// INVENTORY //////////////////////////////////////

/// inventory predefines ////////////////////////
IFNDEF ADV_DEF_INVENT_P;
	BMAP invent_map, <invent.bmp>;     // 12 box inventory panel
	BMAP invent_item_map, <items.bmp>;// inventory items

	BMAP i1_map, <invent.bmp>, 2, 2, 62, 70;	// 1 box of the 12 box inventory panel
	BMAP i2_map, <invent.bmp>, 66, 2, 62, 70;
	BMAP i3_map, <invent.bmp>, 2, 72, 62, 62;
	BMAP i4_map, <invent.bmp>, 66, 72, 62, 62;
	BMAP i5_map, <invent.bmp>, 2, 135, 62, 62;
	BMAP i6_map, <invent.bmp>, 66, 135, 62, 62;
	BMAP i7_map, <invent.bmp>, 2, 197, 62, 62;
	BMAP i8_map, <invent.bmp>, 66, 197, 62, 62;
	BMAP i9_map, <invent.bmp>, 2, 260, 62, 58;
	BMAP i10_map, <invent.bmp>, 66, 260, 62, 58;
	BMAP i11_map, <invent.bmp>, 2, 320, 62, 62;
	BMAP i12_map, <invent.bmp>, 66, 320, 62, 62;

	DEFINE INVENT_P_invent_temp_item_DX		70;	// width of each item stored in invent_item_map

	DEFINE INVENT_P_X		387;	 		// inventory panel upper left border position
	DEFINE INVENT_P_Y		  4;

	DEFINE INVENT_P_WIN_DX		70;	// cutout window size
	DEFINE INVENT_P_WIN_DY		70;

	DEFINE INVENT_P_ROW_1		  2;	// row offsets for inventory panel
	DEFINE INVENT_P_ROW_2		 72;
	DEFINE INVENT_P_ROW_3		135;
	DEFINE INVENT_P_ROW_4		197;
	DEFINE INVENT_P_ROW_5		260;
	DEFINE INVENT_P_ROW_6		320;

	DEFINE INVENT_P_COL_1		 2;   // column offsets for inventory panel
	DEFINE INVENT_P_COL_2		66;


ENDIF;


/// inventory skills ////////////////////////
SKILL i1_window {VAL 0;}
SKILL i2_window {VAL 0;}
SKILL i3_window {VAL 0;}
SKILL i4_window {VAL 0;}
SKILL i5_window {VAL 0;}
SKILL i6_window {VAL 0;}
SKILL i7_window {VAL 0;}
SKILL i8_window {VAL 0;}
SKILL i9_window {VAL 0;}
SKILL i10_window {VAL 0;}
SKILL i11_window {VAL 0;}
SKILL i12_window {VAL 0;}


SKILL i1_status {VAL 0;}# selects the item to be shown in this inv.box
SKILL i2_status {VAL 0;}
SKILL i3_status {VAL 0;}
SKILL i4_status {VAL 0;}
SKILL i5_status {VAL 0;}
SKILL i6_status {VAL 0;}
SKILL i7_status {VAL 0;}
SKILL i8_status {VAL 0;}
SKILL i9_status {VAL 0;}
SKILL i10_status {VAL 0;}
SKILL i11_status {VAL 0;}
SKILL i12_status {VAL 0;}


SKILL __INVENT_STATE {VAL OFF;}	// Inventory State: ON = Open, OFF = Closed


SYNONYM invent_toggle_syn {TYPE ACTION;DEFAULT vinv_show_inventory;}   // switch between vinv_show_inventory and vinv_hide_inventory

SKILL invent_temp_item {VAL _EMPTY;}    // temp hold the current item

SKILL invent_box_number {VAL 0;}		// inventory box number (1..12)
SKILL invent_box_content {VAL _EMPTY;}// temporary buffer: box content


/// inventory panels ////////////////////////
//
// Desc: The 12-box inventory panel.  Uses the defines set in  ADV_DEF_INVENT_P
PANEL invent_pan
{
	POS_X INVENT_P_X;     // set position
	POS_Y INVENT_P_Y;

	BMAP invent_map;      // inventory panel bitmap

	BUTTON INVENT_P_COL_1, INVENT_P_ROW_1, i1_map, NULL, NULL, _vinv_check_i1, NULL, NULL; // each box is a button
	BUTTON INVENT_P_COL_2, INVENT_P_ROW_1, i2_map, NULL, NULL, _vinv_check_i2, NULL, NULL;
	BUTTON INVENT_P_COL_1, INVENT_P_ROW_2, i3_map, NULL, NULL, _vinv_check_i3, NULL, NULL;
	BUTTON INVENT_P_COL_2, INVENT_P_ROW_2, i4_map, NULL, NULL, _vinv_check_i4, NULL, NULL;
	BUTTON INVENT_P_COL_1, INVENT_P_ROW_3, i5_map, NULL, NULL, _vinv_check_i5, NULL, NULL;
	BUTTON INVENT_P_COL_2, INVENT_P_ROW_3, i6_map, NULL, NULL, _vinv_check_i6, NULL, NULL;
	BUTTON INVENT_P_COL_1, INVENT_P_ROW_4, i7_map, NULL, NULL, _vinv_check_i7, NULL, NULL;
	BUTTON INVENT_P_COL_2, INVENT_P_ROW_4, i8_map, NULL, NULL, _vinv_check_i8, NULL, NULL;
	BUTTON INVENT_P_COL_1, INVENT_P_ROW_5, i9_map, NULL, NULL, _vinv_check_i9, NULL, NULL;
	BUTTON INVENT_P_COL_2, INVENT_P_ROW_5, i10_map, NULL, NULL, _vinv_check_i10, NULL, NULL;
	BUTTON INVENT_P_COL_1, INVENT_P_ROW_6, i11_map, NULL, NULL, _vinv_check_i11, NULL, NULL;
	BUTTON INVENT_P_COL_2, INVENT_P_ROW_6, i12_map, NULL, NULL, _vinv_check_i12, NULL, NULL;

	// cutout windows from the inventory items map displayed in the proper item boxes
	WINDOW INVENT_P_COL_1, INVENT_P_ROW_1, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i1_window, 0;  // cutout windows
	WINDOW INVENT_P_COL_2, INVENT_P_ROW_1, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i2_window, 0;
	WINDOW INVENT_P_COL_1, INVENT_P_ROW_2, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i3_window, 0;
	WINDOW INVENT_P_COL_2, INVENT_P_ROW_2, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i4_window, 0;
	WINDOW INVENT_P_COL_1, INVENT_P_ROW_3, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i5_window, 0;
	WINDOW INVENT_P_COL_2, INVENT_P_ROW_3, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i6_window, 0;
	WINDOW INVENT_P_COL_1, INVENT_P_ROW_4, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i7_window, 0;
	WINDOW INVENT_P_COL_2, INVENT_P_ROW_4, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i8_window, 0;
	WINDOW INVENT_P_COL_1, INVENT_P_ROW_5, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i9_window, 0;
	WINDOW INVENT_P_COL_2, INVENT_P_ROW_5, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i10_window, 0;
	WINDOW INVENT_P_COL_1, INVENT_P_ROW_6, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i11_window, 0;
	WINDOW INVENT_P_COL_2, INVENT_P_ROW_6, INVENT_P_WIN_DX, INVENT_P_WIN_DY, invent_item_map, i12_window, 0;

	LAYER 3;    //set layer
	FLAGS REFRESH, OVERLAY;  //redrawn every frame cycle, color #0 not drawn
}





/// inventory actions ////////////////////////

// NOTE: the actions vinv_reset_critical_items and vinv_critical_items should be
//      overriden in the local WDL file

// Desc: reset all critical items
//
// NOTE: override is action in local WDL
ACTION vinv_reset_critical_items
{
	WAIT 1;
}

// Desc: check to see if a critical item has been picked up or lost
//
// NOTE: override is action in local WDL
ACTION vinv_critical_items
{
	WAIT 1;
}


// Desc: reset inventory at game start
ACTION vinv_reset_inventory
{
	SET i1_status, 0;
	SET i2_status, 0;
	SET i3_status, 0;
	SET i4_status, 0;
	SET i5_status, 0;
	SET i6_status, 0;
	SET i7_status, 0;
	SET i8_status, 0;
	SET i9_status, 0;
	SET i10_status, 0;
	SET i11_status, 0;
	SET i12_status, 0;
	CALL _vinv_update_inventory_content;
}


// Desc: show the inventory to player
ACTION vinv_show_inventory
{
	// if buttons are not active...
 	IF (__ICON_ACTIVE == OFF)
 	{
		// don't show inventory
 		RETURN;
 	}
	SET invent_pan.VISIBLE, ON;  // show the inventory panel
	SET invent_toggle_syn, vinv_hide_inventory;   // toggle to vinv_hide_inventory
	SET __INVENT_STATE, ON;             // flag inventory as open
}


// Desc: hide the inventory from player
ACTION vinv_hide_inventory
{
	SET invent_pan.VISIBLE, OFF; // hide the inventory panel
	SET invent_toggle_syn, vinv_show_inventory;   // toggle to vinv_show_inventory
   PLAY_SOUND klick_snd,0.5;
	SET __INVENT_STATE, OFF;            // flag inventory as closed
}

// Desc: toggle the visability of the player's inventory
ACTION vinv_toggle_inventory
{
	CALL invent_toggle_syn;      // show/hide inventory
}






// Desc: put the value stored in invent_temp_item into the next empty box
//      in inventory.  If no room, 'release' item (drop, throw, etc)
ACTION vinv_put_item_inventory
{
	invent_box_content = invent_temp_item;
	IF (i1_status == _EMPTY)
	{
		SET i1_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i2_status == _EMPTY)
	{
		SET i2_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i3_status == _EMPTY)
	{
		SET i3_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i4_status == _EMPTY)
	{
		SET i4_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i5_status == _EMPTY)
	{
		SET i5_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i6_status == _EMPTY)
	{
		SET i6_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i7_status == _EMPTY)
	{
		SET i7_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i8_status == _EMPTY)
	{
		SET i8_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i9_status == _EMPTY)
	{
		SET i9_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i10_status == _EMPTY)
	{
		SET i10_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i11_status == _EMPTY)
	{
		SET i11_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}
	IF (i12_status == _EMPTY)
	{
		SET i12_status, invent_temp_item;
		CALL _vinv_update_inventory_content;
		CALL vinv_critical_items;
		RETURN;
	}

	// no room in inventory, item is released
	CALL vitm_release_item;
}



// Desc: go through the player's inventory, if the value in invent_temp_item matches
// on of the items in inventory remove it.
//       venture_return is set to 1 if item is found in inventory, 0 otherwise
ACTION vinv_delete_item_inventory
{

	IF (i1_status == invent_temp_item)
	{
		SET i1_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i2_status == invent_temp_item)
	{
		SET i2_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i3_status == invent_temp_item)
	{
		SET i3_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i4_status == invent_temp_item)
	{
		SET i4_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i5_status == invent_temp_item)
	{
		SET i5_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i6_status == invent_temp_item)
	{
		SET i6_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i7_status == invent_temp_item)
	{
		SET i7_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i8_status == invent_temp_item)
	{
		SET i8_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i9_status == invent_temp_item)
	{
		SET i9_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i10_status == invent_temp_item)
	{
		SET i10_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i11_status == invent_temp_item)
	{
		SET i11_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}
	IF (i12_status == invent_temp_item)
	{
		SET i12_status, _EMPTY;
		CALL _vinv_update_inventory_content;
		venture_return = 1;
		RETURN;
	}

	// item not found, nothing removed
	venture_return = 0;
}


// Desc: If we have a mouse_object, put/swap the object into inventory (by Calling inventory_put)
//       Else, get an item out of inventory and place it in the mouse_object
//
// Notes: Called from i1_check ... i12_check,
//        box should be set to the selected inventory box and invent_box_content should be
//       set to the content of that box before calling this action.
ACTION _vinv_check_inventory
{
	IF (mouse_object == _EMPTY)		// if we have nothing on the mouse....
	{
		BRANCH _vinv_get_inventory; 		// ...get item from inventory
	}
	CALL _vinv_put_inventory; 			// else put/swap items in inventory
}


// Desc: put the mouse_object item into inventory
//			if an item already exists in that box, exchange them
//
// Called by _vinv_check_inventory
ACTION _vinv_put_inventory
{
	IF (invent_box_content > _EMPTY)	// if an item already exists in that box...
	{
		BRANCH _vinv_exchange_inventory;	// exchange mouse item with box item
	}
	SET invent_box_content, mouse_object; 	// else place mouse_object into inventory
	SET mouse_object, _EMPTY; 	 	// and clear the mouse_object

	CALL _vinv_update_inventory;     	// update the inventory
}


// Desc: exchange the item on the mouse with the item in the inventory
// box the player clicked on.
//
// Called by _vinv_put_inventory
ACTION _vinv_exchange_inventory
{
	// swap items
	SET venture_temp, mouse_object;
	SET mouse_object, invent_box_content; 	// place inventory item on mouse
	SET invent_box_content, venture_temp; 	// place what was on the mouse into inventory
	CALL _vinv_update_inventory;   		// update the inventory
}


// Desc: get the item from the current box and place it in the mouse_object
//
// Called by _vinv_check_inventory
ACTION _vinv_get_inventory
{
	IF (invent_box_content > _EMPTY)
	{
		SET mouse_object, invent_box_content; # inventory -> mouse
		SET invent_box_content, _EMPTY; # clear inventory
	}
	CALL _vinv_update_inventory;
}


// Desc: update the player's inventory after inventory_put, inventory_exchange,
//      or inventory_get is called.
//
// Called by inventory_put, inventory_exchange, and inventory_get
ACTION _vinv_update_inventory
{
	IF (invent_box_number == 1)
	{
		SET i1_status, invent_box_content;
	} # copy the temporary buffer to the box
	IF (invent_box_number == 2)
	{
		SET i2_status, invent_box_content;
	}
	IF (invent_box_number == 3)
	{
		SET i3_status, invent_box_content;
	}
	IF (invent_box_number == 4)
	{
		SET i4_status, invent_box_content;
	}
	IF (invent_box_number == 5)
	{
		SET i5_status, invent_box_content;
	}
	IF (invent_box_number == 6)
	{
		SET i6_status, invent_box_content;
	}
	IF (invent_box_number == 7)
	{
		SET i7_status, invent_box_content;
	}
	IF (invent_box_number == 8)
	{
		SET i8_status, invent_box_content;
	}
	IF (invent_box_number == 9)
	{
		SET i9_status, invent_box_content;
	}
	IF (invent_box_number == 10)
	{
		SET i10_status, invent_box_content;
	}
	IF (invent_box_number == 11)
	{
		SET i11_status, invent_box_content;
	}
	IF (invent_box_number == 12)
	{
		SET i12_status, invent_box_content;
	}
	CALL vinv_critical_items;
	CALL _vinv_update_inventory_content;
	PLAY_SOUND klick_snd, 1;
}


// Desc: set each widow box in the inventory to show the proper content
ACTION _vinv_update_inventory_content
{
	i1_window = i1_status * INVENT_P_invent_temp_item_DX;
	i2_window = i2_status * INVENT_P_invent_temp_item_DX;
	i3_window = i3_status * INVENT_P_invent_temp_item_DX;
	i4_window = i4_status * INVENT_P_invent_temp_item_DX;
	i5_window = i5_status * INVENT_P_invent_temp_item_DX;
	i6_window = i6_status * INVENT_P_invent_temp_item_DX;
	i7_window = i7_status * INVENT_P_invent_temp_item_DX;
	i8_window = i8_status * INVENT_P_invent_temp_item_DX;
	i9_window = i9_status * INVENT_P_invent_temp_item_DX;
	i10_window = i10_status * INVENT_P_invent_temp_item_DX;
	i11_window = i11_status * INVENT_P_invent_temp_item_DX;
	i12_window = i12_status * INVENT_P_invent_temp_item_DX;
}






// Desc: actions to check each of the 12 boxes
//
//  Called when an inventory box button is clicked
//
//  These actions are attached to each of the inventory panels 12 item box
// buttons. When an inventory button is clicked on by the player one of two
// things will happen.
//
// 1) If the player has an item on the mouse cursor that item is placed into
// inventory and any item already in that inventory box is place on the mouse
// cursor.
//
// 2) If the player doesnt have an item on the mouse cursor, any item in
// the inventory box is place on the mouse cursor.
//
//  These actions call _vinv_check_inventory, vinv_inventory_exchange, vinv_inventory_put,
// inventory_get, and inventory_result.
ACTION _vinv_check_i1
{
	SET invent_box_number, 1;		// store the box number
	SET invent_box_content, i1_status; 	// store box contents
	CALL _vinv_check_inventory; 		// call '_vinv_check_inventory' to preform the appropriate action
}
ACTION _vinv_check_i2
{
	SET invent_box_number, 2;
	SET invent_box_content, i2_status;
	CALL _vinv_check_inventory;
}
ACTION _vinv_check_i3
{
	SET invent_box_number, 3;
	SET invent_box_content, i3_status;
	CALL _vinv_check_inventory;
}
ACTION _vinv_check_i4
{
	SET invent_box_number, 4;
	SET invent_box_content, i4_status;
	CALL _vinv_check_inventory;
}
ACTION _vinv_check_i5
{
	SET invent_box_number, 5;
	SET invent_box_content, i5_status;
	CALL _vinv_check_inventory;
}
ACTION _vinv_check_i6
{
	SET invent_box_number, 6;
	SET invent_box_content, i6_status;
	CALL _vinv_check_inventory;
}
ACTION _vinv_check_i7
{
	SET invent_box_number, 7;
	SET invent_box_content, i7_status;
	CALL _vinv_check_inventory;
}
ACTION _vinv_check_i8
{
	SET invent_box_number, 8;
	SET invent_box_content, i8_status;
	CALL _vinv_check_inventory;
}
ACTION _vinv_check_i9
{
	SET invent_box_number, 9;
	SET invent_box_content, i9_status;
	CALL _vinv_check_inventory;
}
ACTION _vinv_check_i10
{
	SET invent_box_number, 10;
	SET invent_box_content, i10_status;
	CALL _vinv_check_inventory;
}
ACTION _vinv_check_i11
{
	SET invent_box_number, 11;
	SET invent_box_content, i11_status;
	CALL _vinv_check_inventory;
}
ACTION _vinv_check_i12
{
	SET invent_box_number, 12;
	SET invent_box_content, i12_status;
	CALL _vinv_check_inventory;
}




//////////////////////// COMBAT /////////////////////////////////////////

/// combat predefines ////////////////////////
IFNDEF ADV_DEF_COMBAT_SND;
  SOUND weapon_swing_snd, <swing.wav>;
  SOUND weapon_hit_snd, <hit.wav>;
  SOUND player_hurt_snd, <ahh.wav>;      // sound played when player takes damage
ENDIF;



/// combat skills ////////////////////////
SKILL player_hp_minus {}				// damage applied to player

SKILL vent_npc_str {}            // current STRENGTH, AGILITY, BRAVERY, and INTUITION values of the NPC
SKILL vent_npc_gew {}
SKILL vent_npc_mut {}
SKILL vent_npc_int {}

SKILL vent_attack_value {}       	// current attack value
SKILL vent_defense_value {}         // current defense value

SKILL hp_minus {} 						// damage taken from last attack


/// combat actions ////////////////////////

// Desc:	This action is called to handle attacks on the player.
//
//			Use the STR, MUT, and GEW skills (defined else ware) to calculate an
//      attack on the player.  The player uses their player_mut, gew, and int
//      skills to defend.
//
//       Damage to the player is calculated (player_current_hp is reduced)
//		  and (if damage is greater than zero) player hit is called.
ACTION vcom_player_defense
{
	vent_attack_value =  (vent_npc_str + vent_npc_mut + vent_npc_gew) / 3; // calculate the NPC attack value
	venture_temp =  (player_mut + player_gew + player_int) / 3; 														// calculate player defense value
	player_hp_minus = RANDOM (vent_attack_value / venture_temp * 10); // calculate the damage done by the attack
	player_hp_minus = INT (player_hp_minus);
	player_current_hp = player_current_hp - player_hp_minus;
	IF (player_hp_minus > 0)                                          // apply damage
	{
		CALL vcom_player_hit;
	}
}


// Desc: This action is called to handle attack by the player.
//
//			Use the player's player_mut, gew, and str to calculate there attack.
//			Use the INT, MUT, and GEW skills (defined else ware) to calculate
//      the defense from the player's attack.
//
//       Damage is calculated and applied to the calling entity's _HEALTH
//      skill. If the entity's _HEALTH skill < 0, its _STATE is set to _NPC_DEAD.
ACTION vcom_player_attack
{
	vent_defense_value =  (vent_npc_gew + vent_npc_mut + vent_npc_int) / 3; // calculate the NPC defense value
		venture_temp =  (player_mut + player_gew + player_str) / 3; 														// calculate the player attack value
	hp_minus = RANDOM (venture_temp / vent_defense_value * 10); // calculate the damage done by the attack
	hp_minus = INT (hp_minus);
	MY._HEALTH = MY._HEALTH - hp_minus;                         // apply damage

	IF (MY._HEALTH <= 0)
	{
		MY._STATE = _NPC_DEAD;
	}
}

// Desc: This action is called to handle when the player gets hit.
//
//			If the hit has reduced the player's hitpoints to zero or less
//      BRANCH to player_dead.
//
//       Else, play the hurt sound, and flash the blood panel.
ACTION vcom_player_hit
{
	IF (player_current_hp <= 0)
	{
		BRANCH vcom_player_dead;
	}
	IF (PLAYER.__BUSY)
	{
		RETURN;
	}
	SET PLAYER.__BUSY, ON;
	PLAY_SOUND player_hurt_snd, 40;
	SET blood_pan.TRANSPARENT, ON;
	SET blood_pan.VISIBLE, ON;
	WAITT 1;
	SET blood_pan.VISIBLE, OFF;
	SET PLAYER.__BUSY, OFF;
}



// Desc: This action is called to handle when the player dies.
//
//			Reset the keys, flash blood panel, FREEZE the character, and
//		  show the main menu.
ACTION vcom_player_dead
{
	CALL vinp_reset_keys;   // restrict player input
 	SET blood_pan.VISIBLE, ON;
	SET blood_pan.TRANSPARENT, ON;
  	WAITT 1;
	SET blood_pan.TRANSPARENT, OFF;
	CALL vscr_show_admenu;   // show the after death menu
   FREEZE_MODE = 1;	// freeze the game
}





/// combat sword defines ////////////////////////

DEFINE	_VWEAPON_TYPE,SKILL19;	// used to define the type of weapon this is
DEFINE	_VWEAPON_TYPE_MELEE,1;	// melee weapon
DEFINE	_VWEAPON_TYPE_DIRECT,2;	// direct damage weapon (fireball)

SKILL __HAS_SWORD {VAL OFF;} 	// set 'ON' to allow player to use sword
SKILL __WIELD_SWORD {VAL OFF;}	// 'ON' to wield the sword ('OFF' to shieth)
SKILL __SHEATHE_SWORD {VAL OFF;}// 'ON' to temp sheathe sword while pointer is on
SKILL __BLOODY {}                // 'ON' for blood, 'OFF' for sparks

/// combat sword skills ////////////////////////
SKILL sw_dist {}
SKILL sw_pos {}
SKILL sw_temp {}
SKILL sw_normal {}
SKILL strike_dir {}
SKILL strike_angle {}


/// combat sword actions ////////////////////////

// Desc: create a sword object, set SPACE to remove sword
//       __HAS_SWORD flag must be set ON
ACTION vcom_create_sword
{
	IF (__HAS_SWORD == ON)
	{
		__WIELD_SWORD = ON;
		CREATE <sw_arm.mdl>, MY_POS, _vcom_carry_sword;
		SET ON_SPACE, _vcom_remove_sword;
	}
}

// Desc: set the sword carry flag to off
ACTION _vcom_remove_sword
{
	__WIELD_SWORD = OFF;
}

// Desc: carry the sword, action attached to the sword model
// Note: the sword's tilt is attached to the camera view to allow the user
//      to aim up and down.
//
ACTION _vcom_carry_sword
{
	MY.SCALE_X = 0.5;
	MY.SCALE_Y = 0.5;
	MY.SCALE_Z = 0.5;
	SET MY.NEAR, ON;
	SET MY.PASSABLE, ON;

	SET MY._VWEAPON_TYPE,_VWEAPON_TYPE_MELEE;

	while (1)
	{

		// sheathe the sword while mouse pointer is on
		IF (__SHEATHE_SWORD == ON)
		{
			REMOVE ME;
			RETURN;		// exit carry sword action
		}


  		// remove sword...
		IF (__WIELD_SWORD == OFF)
		{

			__SHEATHE_SWORD = OFF;	// don't draw sword when mouse pointer is off
			REMOVE ME;
			SET ON_SPACE, vcom_create_sword;
			RETURN;		// exit carry sword action
		}

		// Line the sword model up with the player and camera
		sw_dist = 13 + 0.2 * CAMERA.TILT;
		venture_temp.X = COS (PLAYER.PAN);
		venture_temp.Y = SIN (PLAYER.PAN);
		venture_temp.Z = sw_dist * COS (CAMERA.TILT);
		MY.X = PLAYER.X + venture_temp.Z * venture_temp.X;
		MY.Y = PLAYER.Y + venture_temp.Z * venture_temp.Y;
		MY.Z = PLAYER.Z + SIN (CAMERA.TILT);
		MY.PAN = PLAYER.PAN - 180;
		MY.TILT = -CAMERA.TILT + 10;


		// swing the sword...
		IF (MY.__BUSY == OFF &&  (KEY_CTRL == ON || MOUSE_LEFT == ON))
		{
			// swing sword
			CALL _vcom_swing_sword;

			// reduce player's strength
 			player_current_str -= 2;
			IF (player_current_str <= 0)
			{
				// note: you shouldn't die just because you're out of str
				player_current_str = 0;
			}
		}


		WAIT 1;
	}
}


// Calculate a 3d position relative to the camera angles
// Input:  p (distance)
// Output: MY_POS
ACTION _vcom_find_sword_edge
{
   venture_temp.Z = p * COS (CAMERA.TILT);
	venture_temp.X = COS (PLAYER.PAN);
	venture_temp.Y = SIN (CAMERA.PAN);

	MY_POS.X = MY.X + venture_temp.Z * venture_temp.X;
	MY_POS.Y = MY.Y + venture_temp.Z * venture_temp.Y;
	MY_POS.Z = MY.Z + p * SIN (CAMERA.TILT);
}

//Desc: Animate the sword, check to see if it hit anything
ACTION _vcom_swing_sword
{
	SET MY.__BUSY, ON;
	MY.CYCLE = 2;

	WHILE (MY.CYCLE != 1)
	{
		MY.CYCLE += 1;

		// shoot a ray out twice during the swinging action
		IF (MY.CYCLE == 10 || MY.CYCLE == 18)
		{
			p = 80;                 // set p to the sword length
			CALL _vcom_find_sword_edge;
			SHOOT MY.POS, MY_POS;   // shoot a ray along the sword edge

			// If we hit something with SHOOT...
			IF (RESULT > 0)
			{
				sw_temp = RESULT;

				PLAY_SOUND weapon_hit_snd, 50;
				IF (__BLOODY == ON)
				{
					// show hit on target
					CALL _vcom_show_blood_strike;
				}
				ELSE
				{
					// show 'spark' hit (no-blood)
					CALL _vcom_show_wall_strike;
				}
			}
		}
		IF (MY.CYCLE == 8 || MY.CYCLE == 15)
		{
			PLAY_SOUND weapon_swing_snd, 50;
		}
		IF (MY.CYCLE > 18)
		{
			MY.CYCLE = 1;
			SET MY.__BUSY, OFF;
		}
		WAITT 1;
	}
}


// Desc: show a hit on a 'flesh' target
ACTION _vcom_show_blood_strike
{
	CREATE <blood+4.pcx>, TARGET, _vcom_splat;
}


// Desc: show a hit on a 'non-flesh' target
ACTION _vcom_show_wall_strike
{
	CREATE <glow+4.pcx>, TARGET, _vcom_splat;
}


// Desc: wall and blood strike actions
ACTION _vcom_splat
{
	IF (__BLOODY == ON)
	{
		CALL scatter_init;
		scatter_size = 1;
		scatter_color.RED = 255;
		scatter_color.GREEN = 0;
		scatter_color.BLUE = 0;
		fade_color.RED = 255;
		fade_color.GREEN = 0;
		fade_color.BLUE = 0;
		EMIT 100, particle_pos, particle_traces;
	}
	ELSE
	{
		CALL scatter_init;
		EMIT 100, particle_pos, particle_range;
	}
	MY.SCALE_X = 0.1;
	MY.SCALE_Y = 0.1;
	SET MY.FACING, ON;
	SET MY.PASSABLE, ON;
	SET MY.NEAR, ON;
	SET MY.TRANSPARENT, ON;
	MY.CYCLE = 1;
	sw_normal = 0.1;
	WHILE (MY.CYCLE < 4)
	{
		MY.CYCLE += 0.5 * TIME;
		strike_dir.X = player.X - MY.X;
		strike_dir.Y = player.Y - MY.Y;
		strike_dir.Z = player.Z - MY.Z;
		TO_ANGLE, strike_angle, strike_dir;
		MY.PAN += ANG (strike_angle.PAN - MY.PAN);
		SET YOU,NULL;
		MOVE ME sw_normal, NULLSKILL;
		WAITT 1;
	}
	REMOVE ME;
}




// Desc: Apply damage directly to the entity
// NOTE: hp_minus must be set before calling this action
ACTION vcom_direct_attack
{
 	hp_minus = INT (hp_minus);
	MY._HEALTH = MY._HEALTH - hp_minus;                         // apply damage

	IF (MY._HEALTH <= 0)
	{
		MY._STATE = _NPC_DEAD;
	}
}




//////////////////////// DIALOG /////////////////////////////////////////

/// dialog skills ////////////////////////
SKILL actor_dialog_b1 {}
SKILL actor_dialog_b2 {}
SKILL actor_dialog_b3 {}
SKILL exit1 {}
SKILL exit2 {}
SKILL exit3 {}


/// dialog defines ////////////////////////
DEFINE _DIALOG_STATE, SKILL33;  // Used to store the current dialog state


/// dialog strings ////////////////////////
// a blank text string for initializing the
STRING blank_dialog_str, "






                ";



/// dialog text ////////////////////////
TEXT dialog_txt
{
	POS_X 100;
	POS_Y 355;
	LAYER 5;
	FONT panel_font;
	STRING blank_dialog_str;
	FLAGS CONDENSED;
}



/// dialog panels ////////////////////////

// Desc: Two button dialog panel
PANEL dialog1_button_panel
{
	POS_X 61;
	POS_Y 265;
	BUTTON 15, 130, button_map, button_map, button_map, _vdia_button1, NULL, NULL;
	BUTTON 15, 160, button_map, button_map, button_map, _vdia_button2, NULL, NULL;
	LAYER 5;
	FLAGS REFRESH, OVERLAY;
}

// Desc: Single button dialog panel
PANEL dialog2_button_panel
{
	POS_X 61;
	POS_Y 265;
	BUTTON 200, 180, button_map, button_map, button_map, _vdia_button3, NULL, NULL;
	LAYER 5;
	FLAGS REFRESH, OVERLAY;
}


/// dialog actions ////////////////////////

// Desc: This action handles dialog between the player and the NPC's.
//
//	Note: This code is specific to the adventure being written.  It over-
//		  rides the 'dummy' action in venture.wdl
ACTION vdia_make_talk
{
	beep;
}


// Desc: Make the info2 panel and dialog text visible.
ACTION vdia_show_dialog
{
	SET info2_pan.VISIBLE, ON;
	SET dialog_txt.VISIBLE, ON;
}


// Desc: button 1 action
ACTION _vdia_button1
{
	SET NPC_ENTITY._DIALOG_STATE, actor_dialog_b1;
	IF (exit1 == ON)
	{
		CALL vscr_close_all;
		NPC_ENTITY._STATE = _NPC_WALK;
		RETURN;
	}
	CALL vdia_make_talk;
}

// Desc: button 2 action
ACTION _vdia_button2
{
	SET NPC_ENTITY._DIALOG_STATE, actor_dialog_b2;
	IF (exit2 == ON)
	{
		CALL vscr_close_all;
		NPC_ENTITY._STATE = _NPC_WALK;
		RETURN;
	}
	CALL vdia_make_talk;
}

// Desc: button 3 action
ACTION _vdia_button3
{
	SET NPC_ENTITY._DIALOG_STATE, actor_dialog_b3;
	IF (exit3 == ON)
	{
		CALL vscr_close_all;
		NPC_ENTITY._STATE = _NPC_WALK;
		RETURN;
	}
	CALL vdia_make_talk;
}




//////////////////////// SPELLS /////////////////////////////////////////
// The following actions deal with spell casting and their effects
//

/// spell skills ////////////////////////
SKILL vsk_fb_speed {X 30; Y 0; Z 0;}

/// spell sounds ////////////////////////
SOUND zisch_snd, <whosh.wav>;
SOUND schuss_snd, <explosin.wav>;


/// spell actions ////////////////////////

// Desc: have the player cast a fireball
ACTION vspl_player_cast_fireball
{
	ME = PLAYER;
	CALL vspl_cast_fireball;
}


// Desc: cast a fireball
// NOTE: MY should be set to the caster.
ACTION vspl_cast_fireball
{
   venture_temp.Z = 35 * COS (MY.TILT);
	venture_temp.X = COS (MY.PAN);
	venture_temp.Y = SIN (MY.PAN);


	MY_POS.X = MY.X + venture_temp.Z * venture_temp.X;
	MY_POS.Y = MY.Y + venture_temp.Z * venture_temp.Y;
	MY_POS.Z = MY.Z + 35 * SIN (MY.TILT);


 	CREATE <fball.pcx>, MY_POS, _vspl_fball_action;   // create a fireball entity
}

// Desc: fireball action
ACTION _vspl_fball_action
{
	SET MY._VWEAPON_TYPE,_VWEAPON_TYPE_DIRECT;
	SET MY.ENTITY1, YOU;		// link back to the caster
	MY.AMBIENT = 100;
	#	SET MY.TRANSPARENT, ON;
	#	MY.SCALE_X = 1;
	MY.LIGHTRANGE = 400;
	MY.LIGHTRED = 50;
	MY.LIGHTGREEN = 50;
	MY.LIGHTBLUE = 200;
	SET MY.PAN,  YOUR.PAN; // let it fly in view direction, like a bullet
	SET MY.ROLL, YOUR.ROLL;
	SET MY.TILT, YOUR.TILT;
	SET MY.EVENT, _vspl_fball_event;
	SET MY.ENABLE_BLOCK, ON;
	SET MY.ENABLE_ENTITY, ON;
	SET MY.ENABLE_TRIGGER, ON;
	MY.TRIGGER_RANGE = 35;
	WAIT	1;	// for play_entsound
	PLAY_ENTSOUND ME, zisch_snd, 400;


 	WHILE (1)
	{
		//SET YOU,NULL;
		MOVE ME, vsk_fb_speed, nullskill;
		CALL _vspl_fball_particle_init;
		WAIT 1;
	}
}

// Desc: fireball event
ACTION _vspl_fball_event
{
	EXCLUSIVE_ENTITY;	// stop all actions started by this one

	IF (YOU == PLAYER)
	{
		CALL _vspl_fball_hit_player;
		SET MY.ENABLE_TRIGGER, OFF;
	}

	// Explode
	PLAY_ENTSOUND ME,schuss_snd,100;
	MORPH <explo+7.pcx>, ME;
	MY.AMBIENT = 100;
	SET MY.PASSABLE, ON;
	WHILE (MY.CYCLE <= 7)
	{
		MY.CYCLE += TIME;
		WAITT 1;
	}
	REMOVE ME;
}


// Desc: handle a fireball hit on the player
ACTION _vspl_fball_hit_player
{
	player_current_hp -= 15;
	CALL vcom_player_hit;
}


// Desc: initialize the particles falling from the fireball.
ACTION _vspl_fball_particle_init
{
	particle_pos.X = MY.X;
	particle_pos.Y = MY.Y;
	particle_pos.Z = MY.Z;
	EMIT 40, particle_pos, _vspl_fball_particle;
}

// Desc: fireball particles
ACTION _vspl_fball_particle
{
	IF (MY_AGE == 0)
	{
		SET MY_MAP, scatter_map;
		SET MY_FLARE,ON;
		MY_SPEED.X = scatter_speed.X + RANDOM(scatter_spread);
		MY_SPEED.Y = scatter_speed.Y + RANDOM(scatter_spread);
		MY_SPEED.Z = scatter_speed.Z + RANDOM(scatter_spread);
		MY_SIZE = 80;
		MY_COLOR.RED = 255;
		MY_COLOR.GREEN = 255;
		MY_COLOR.BLUE = 255;
	}
	MY_COLOR.RED -= 20;
	MY_COLOR.GREEN -= 15;
	MY_COLOR.BLUE -= 10;
	#IF (MY_AGE > shot_lifetime)
	IF (MY_COLOR.RED <= 20)
	{
		SET MY_ACTION, NULL;
	}
}




//////////////////////// INPUT //////////////////////////////////////////
// These are actions manage the user's input (mouse/keyboard)
//

/// input predefines ////////////////////////
IFNDEF ADV_DEF_CURSOR_MAP;
	BMAP mouse_l_map, <arrow.pcx>;  	// mouse cursor image map
ENDIF;

/// input defines ////////////////////////
DEFINE MOUSE_WALK, -1; // mouse walk mode

/// input skills ////////////////////////
SYNONYM vinp_left_mouse_action_syn {TYPE ACTION;}  // action preformed by the left mouse button
SKILL		old_mouse_object {VAL -1;}						// used for comparisons


/// input actions ////////////////////////

// Desc: initialize the mouse settings
ACTION vinp_init_mouse
{
	MOUSE_RANGE = 400;
}

// Desc: switches the mouse pointer on and off
//
// NOTE: if MOUSE_MODE > 2, _vinp_mouse_hnadler will turn it off and put
//      any mouse_objects into inventory
ACTION vinp_toggle_mouse
{
	MOUSE_MODE += 2;
 	CALL _vinp_update_mouse;
}

// Desc: switch mouse on
ACTION vinp_show_mouse
{
	MOUSE_MODE = 2; // switches the mouse on
	CALL _vinp_update_mouse;
}

// Desc: switch mouse off
ACTION vinp_hide_mouse
{
	MOUSE_MODE = 0; // switches the mouse off
	CALL _vinp_update_mouse;
}

// Desc: if there is an object on the mouse, place it in the first empty slot
// in the inventory
ACTION vinp_clear_mouse_to_inventory
{
	IF (mouse_object > _EMPTY)
	{
		//place the mouse object into the first empty space
		invent_temp_item = mouse_object;     // set the item to the mouse_object
		CALL vinv_put_item_inventory; // put the item in the next empty slot in inventory
		SET mouse_object, _EMPTY; // clear the mouse_object
   }
}

// Desc: handle updates to the mouse (movement, mouse_object change, etc)
ACTION _vinp_update_mouse
{
	MOUSE_RANGE = 400;

	//
	IF (MOUSE_MODE > 2)// hide mouse pointer
	{
		CALL vinp_clear_mouse_to_inventory; // place mouse_object into inventory
		mouse_object = MOUSE_WALK;          // mouse can be used to walk
		MOUSE_MODE = 0;
		CALL vttx_hide_touch_text;          // no touch text
		CALL vinv_hide_inventory;           // hide inventory box

	 	// draw sheathed sword (if it was drawn before)
		IF (__SHEATHE_SWORD == ON)
		{
			__SHEATHE_SWORD = OFF;	// sword no longer sheathed
			CALL vcom_create_sword;
		}

		RETURN;
	}

	// sheathe sword before showing mouse pointer
	IF (__WIELD_SWORD == ON)
	{
		__SHEATHE_SWORD = ON;
	}

	SET vinp_left_mouse_action_syn, NULL;
	SET MOUSE_MAP, mouse_l_map;
	MOUSE_POS.X = 256;
	MOUSE_POS.Y = 190;
	mouse_object = MOUSE_WALK;
	old_mouse_object = mouse_object; //save the current mouse_object temporary


	WHILE (MOUSE_MODE > 0)
	{
		// update the mouse's position
IFDEF ACKNEX_VERSION414;
		MOUSE_POS.X = POINTER.X;
		MOUSE_POS.Y = POINTER.Y;
IFELSE;
		MOUSE_POS.X += MICKEY.X;
		MOUSE_POS.Y += MICKEY.Y;
ENDIF;

		// check to see if the mouse_object has changed
		IF (old_mouse_object != mouse_object)
		{
			CALL _vinp_change_mouse_map; //change the mouse sprite

			// update the old_mouse_object to the current mouse object
			old_mouse_object = mouse_object;
		}


		// If the mousesprite is an item...
		IF (mouse_object > _EMPTY)
		{

			// ...and it is over the inventory and then inventory is closed...
			// !!!DcP- add code to make 'over the inventory' more general
			IF ((MOUSE_POS.X > 512) && (__INVENT_STATE == OFF))
			{
				CALL invent_toggle_syn;         // toggle inventory
				SET vinp_left_mouse_action_syn, NULL;	// deactivate any mouse action
			}

			// ...and it is over the open inventory panel or side bar...
			IF ( (MOUSE_POS.X > 380) && (__INVENT_STATE == ON) )
			{
				SET vinp_left_mouse_action_syn, NULL;     // deactivate any mouse action
			}

			// ...and it is NOT over the open inventory ...
			IF ( (MOUSE_POS.X < 380) && (__INVENT_STATE == ON) )
			{
				CALL invent_toggle_syn;	// close the inventory box
			}

			// ...and it is NOT over the inventory...
			IF (MOUSE_POS.X < 380)
			{
 				SET vinp_left_mouse_action_syn, _vitm_use_item; 	// set left mouse button to use_item
 			}


			}
		ELSE // (mouse_object <= _EMPTY)
		{
			SET vinp_left_mouse_action_syn, NULL;
		}


		SET ON_MOUSE_LEFT, vinp_left_mouse_action_syn;
		WAIT 1;
	}
}

// Desc: change the mouse map to whatever item the user may be holding
//
// Note: calls the user defined action 'vinp_set_mouse_map_to_item'
//
// Called from '_vinp_update_mouse'
ACTION _vinp_change_mouse_map //mouse sprite change
{
	IF (mouse_object > _EMPTY)
	{
		// set the mouse map to the current mouse_object's map
		CALL vinp_set_mouse_map_to_item;
	}
	ELSE
	{
		// no mouse item, revert to mouse cursor
		SET MOUSE_MAP, mouse_l_map;
		MOUSE_SPOT.X = 0;
		MOUSE_SPOT.Y = 0;
	}
}


// Desc: set the mouse map image to that of an item
//
// NOTE: OVERRIDE THIS ACTION IN YOU GAME WDL
ACTION vinp_set_mouse_map_to_item
{
	WAIT 1;
}



// Desc: deactivate keyboard input
ACTION vinp_reset_keys
{
	SET ON_F1, NULL;
	SET ON_F2, NULL;
	SET ON_F3, NULL;
	SET ON_F4, NULL;
	SET ON_F5, NULL;
	SET ON_F6, NULL;
	SET ON_F7, NULL;
	SET ON_F8, NULL;
	SET ON_F9, NULL;
	SET ON_F10, NULL;
	SET ON_F11, NULL;
	SET ON_F12, NULL;
	SET ON_ESC, NULL;
	SET ON_ANYKEY, NULL;
	SET ON_MOUSE_RIGHT vinp_toggle_mouse;
}


// Desc: Initialize key mapping
//
// NOTE: override this action to change your key settings
ACTION vinp_init_keys
{
	SET ON_F1, vscr_toggle_help;
	SET ON_F2, vpic_save;
	SET ON_F3, vpic_load;
	SET ON_F5, NULL;//toggle_detail;
	SET ON_F7, vscr_toggle_credits;
	SET ON_F10, vscr_show_exit;
 	SET ON_F11, NULL;//toggle_gamma;
 	SET ON_ESC, vscr_close_all;
	SET ON_I, vinv_toggle_inventory;
	SET ON_C, vpst_toggle_char;
	SET ON_M, vscr_toggle_menu;
	SET ON_Y, NULL;
	SET ON_J, NULL;
	SET ON_N, NULL;
	SET ON_ANYKEY, NULL;
}



//////////////////////// TOUCH TEXT /////////////////////////////////////
// These actions handle 'touch' text (item text that appears when the
// player 'touches' something with the mouse cursor).
//

/// touch text strings ////////////////////////
STRING vent_null_str, " ";

/// touch text text ////////////////////////
TEXT touch_txt_old
{
	POS_X 320;
	POS_Y 410;
	LAYER 2;
	FONT panel_font;
	STRING vent_null_str;
	FLAGS VISIBLE,CENTER_X;
}
TEXT wrong_item_txt
{
	POS_X 320;
	POS_Y 410;
	LAYER 2;
	FONT panel_font;
	STRING wrong_item_str;
	FLAGS CENTER_X;
}


/// touch text actions ////////////////////////

// Desc: show touch text
ACTION vttx_show_touch_text
{
	 SET touch_txt_old.STRING, MY.STRING1;
}

// Desc: hide touch text
ACTION vttx_hide_touch_text
{
	SET touch_txt_old.STRING, vent_null_str;
}


// Desc: indicate that this is the wrong item
// (hide the touch text and display the wrong item text
// for 2-seconds)
ACTION vttx_show_wrong_item_text
{
	SET touch_txt_old.VISIBLE, OFF;
	SET wrong_item_txt.VISIBLE, ON;
	WAITT 32;
	SET touch_txt_old.VISIBLE, ON;
	SET wrong_item_txt.VISIBLE, OFF;
}



//////////////////////// MISC ///////////////////////////////////////////


/// misc actions ////////////////////////

// Desc: fade to black and exit game.  Display the vstr_exit_txt exit
//      string in the exit window.
ACTION vmsc_exit
{
	SET blood_pan.VISIBLE, OFF;

 	SET blackTop13_pan.VISIBLE, ON;
	WAITT 1;
	SET blackTop14_pan.VISIBLE, ON;
	WAITT 1;
	SET blackTop15_pan.VISIBLE, ON;
	WAITT 1;
	SET blackTop16_pan.VISIBLE, ON;
	WAITT 1;


  	EXIT  vstr_exit_txt;
}





/// screen actions (cont.) ////////////////////////
// Screen actions that require all the venture panels to be defined.

// Desc: Hide all panels and text.
ACTION _vscr_hide_all
{
	CALL _vpic_save_hide;               		// hide save panel

	SET blackTop16_pan.VISIBLE, OFF;          // hide blackout panels
	SET blackTop15_pan.VISIBLE, OFF;
	SET blackTop14_pan.VISIBLE, OFF;
	SET blackTop13_pan.VISIBLE, OFF;

	SET info1_pan.VISIBLE, OFF;              	// hide info1 panel and text
	SET info1_txt.VISIBLE, OFF;
	SET info2_pan.VISIBLE, OFF;               // hide info2 panel and text
	SET info2_txt.VISIBLE, OFF;

	SET start_menu_vbpan.VISIBLE, OFF;        // hide button panels
	SET info_exit_vbpan.VISIBLE, OFF;
	SET intro_exit_vbpan.VISIBLE, OFF;
	SET info_exit_right_vbpan.VISIBLE, OFF;
	SET main_menu_vbpan.VISIBLE, OFF;
  	SET admenu_vbpan.VISIBLE, OFF;
	SET exit_vbpan.VISIBLE, OFF;
	SET start_exit_vbpan.VISIBLE, OFF;

	SET char_pan.VISIBLE, OFF;               	// hide character panels
	SET bonus_pan.VISIBLE, OFF;
	SET bonus_info_txt.VISIBLE, OFF;

	SET dialog_txt.VISIBLE, OFF;              // hide dialog text and panels
	SET dialog1_button_panel.VISIBLE, OFF;
	SET dialog2_button_panel.VISIBLE, OFF;


	// SET toggles
	SET  menu_toggle_syn, vscr_show_menu;		// set menu toggle to show menu
	SET  help_toggle_Syn, vscr_show_help;		// set help toggle to show help
	SET  credit_toggle_Syn, vscr_show_credits;// set help toggle to show credits
	SET  char_toggle_syn, vpst_show_char;		// set char toggle to show char
}




// Desc: Hide all panels, init the keys, enable icons.
ACTION vscr_close_all
{
	CALL _vscr_hide_all;					// hide all panels and text

	CALL vinp_init_keys;       		// init/reactivate keys

	__ICON_ACTIVE = ON;              // allow player to use icons

	PLAY_SOUND klick_snd, 50;
}


// Desc: Hide all panels, reset the keys, disable icons.
ACTION vscr_close_all_at_start
{
	CALL _vscr_hide_all;				  	// hide all panels and text

	CALL vinp_reset_keys;            // reset/disable the keys
	__ICON_ACTIVE = OFF;            	// disable player from using icons
	PLAY_SOUND klick_snd, 50;
}


// Desc: Hide all panels, reset the keys, enable icons.
ACTION vscr_close_all_at_end
{
	CALL _vscr_hide_all;					// hide all panels and text

	CALL vinp_reset_keys;          	// reset/disable the keys
	__ICON_ACTIVE = ON;             	// enable player to use icons
	PLAY_SOUND klick_snd, 50;

}